syntax = "proto3";

package xray.transport.internet.httpupgrade;

message Config {
  string host = 1;
  string path = 2;
  map<string, string> header = 3;
  bool accept_proxy_protocol = 4;
  uint32 ed = 5;
}
