syntax = "proto3";

package xray.transport.internet.grpc.encoding;

message Config {
  string authority = 1;
  string service_name = 2;
  bool multi_mode = 3;
  int32 idle_timeout = 4;
  int32 health_check_timeout = 5;
  bool permit_without_stream = 6;
  int32 initial_windows_size = 7;
  string user_agent = 8;
}
