syntax = "proto3";

package xray.app.dns.fakedns;

message FakeDnsPool{
  string ip_pool = 1; //CIDR of IP pool used as fake DNS IP
  int64  lruSize = 2; //Size of Pool for remembering relationship between domain name and IP address
}

message FakeDnsPoolMulti{
  repeated FakeDnsPool pools = 1;
}