syntax = "proto3";

package xray.transport.internet.http;

import "xcapi/xray/transport/internet/headers/http/config.proto";

message Config {
  repeated string host = 1;
  string path = 2;
  int32 idle_timeout = 3;
  int32 health_check_timeout = 4;
  string method = 5;
  repeated xray.transport.internet.headers.http.Header header = 6;
}
