syntax = "proto3";

package xray.proxy.vless.inbound;

import "xcapi/xray/common/protocol/user.proto";

message Fallback {
  string name = 1;
  string alpn = 2;
  string path = 3;
  string type = 4;
  string dest = 5;
  uint64 xver = 6;
}

message Config {
  repeated xray.common.protocol.User clients = 1;
  // Decryption settings. Only applies to server side, and only accepts "none"
  // for now.
  string decryption = 2;
  repeated Fallback fallbacks = 3;
}
