# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/blackhole/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from typing import Optional
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class NoneResponse(ClassMeta):
    pass


@dataclass
class HTTPResponse(ClassMeta):
    pass


@dataclass
class Config(ClassMeta):
    response: Optional[TypedMessage] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/proxy/blackhole/config.proto\x12\x14xray.proxy.blackhole\x1a,xcapi/xray/common/serial/typed_message.proto\"\x0e\n\x0cNoneResponse\"\x0e\n\x0cHTTPResponse\"<\n\x06\x43onfig\x12\x32\n\x08response\x18\x01 \x01(\x0b\x32 .xray.common.serial.TypedMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.blackhole.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_NONERESPONSE']._serialized_start = 111
    _globals['_NONERESPONSE']._serialized_end = 125
    _globals['_HTTPRESPONSE']._serialized_start = 127
    _globals['_HTTPRESPONSE']._serialized_end = 141
    _globals['_CONFIG']._serialized_start = 143
    _globals['_CONFIG']._serialized_end = 203
