# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/dns/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.destination_pb import Endpoint
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class Config(ClassMeta):
    server: Optional[Endpoint] = None
    """Server is the DNS server address. If specified, this address overrides the original one."""
    user_level: Optional[int] = None
    non_IP_query: Optional[str] = None
    block_types: Optional[List[int]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!xcapi/xray/proxy/dns/config.proto\x12\x0exray.proxy.dns\x1a\'xcapi/xray/common/net/destination.proto\"r\n\x06\x43onfig\x12)\n\x06server\x18\x01 \x01(\x0b\x32\x19.xray.common.net.Endpoint\x12\x12\n\nuser_level\x18\x02 \x01(\r\x12\x14\n\x0cnon_IP_query\x18\x03 \x01(\t\x12\x13\n\x0b\x62lock_types\x18\x04 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.dns.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 94
    _globals['_CONFIG']._serialized_end = 208
