# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.observatory.command import command_pb


class ObservatoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOutboundStatus = channel.unary_unary(
            '/xray.core.app.observatory.command.ObservatoryService/GetOutboundStatus',
            request_serializer=command_pb.GetOutboundStatusRequest.SerializeToString,
            response_deserializer=command_pb.GetOutboundStatusResponse.FromString,
            _registered_method=True)
