syntax = "proto3";

package xray.common.net;

enum Network {
  Unknown = 0;

  TCP = 2;
  UDP = 3;
  UNIX = 4;
}

// NetworkList is a list of Networks.
message NetworkList { repeated Network network = 1; }
