# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/protocol/server_spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from xcapi.xray.common.net.address_pb import IPOrDomain
from xcapi.xray.common.protocol.user_pb import User
from dataclasses import dataclass


@dataclass
class ServerEndpoint(ClassMeta):
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None
    user: Optional[List[User]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,xcapi/xray/common/protocol/server_spec.proto\x12\x14xray.common.protocol\x1a#xcapi/xray/common/net/address.proto\x1a%xcapi/xray/common/protocol/user.proto\"v\n\x0eServerEndpoint\x12,\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\x04user\x18\x03 \x03(\x0b\x32\x1a.xray.common.protocol.Userb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.protocol.server_spec_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERENDPOINT']._serialized_start = 146
    _globals['_SERVERENDPOINT']._serialized_end = 264
