syntax = "proto3";

package xray.proxy.vless;

message Account {
  // ID of the account, in the form of a UUID, e.g., "66ad4540-b58c-4ad2-9926-ea63445a9b57".
  string id = 1;
  // Flow settings. May be "xtls-rprx-vision".
  string flow = 2;
  // Encryption settings. Only applies to client side, and only accepts "none" for now.
  string encryption = 3;
}
