# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/proxyman/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.protocol.user_pb import User
from xcapi.xray.core.config_pb import InboundHandlerConfig, OutboundHandlerConfig
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from dataclasses import dataclass
from typing import Optional
from xcapi.model import ClassMeta


@dataclass
class AddUserOperation(ClassMeta):
    user: Optional[User] = None


@dataclass
class RemoveUserOperation(ClassMeta):
    email: Optional[str] = None


@dataclass
class AddInboundRequest(ClassMeta):
    inbound: Optional[InboundHandlerConfig] = None


@dataclass
class AddInboundResponse(ClassMeta):
    pass


@dataclass
class RemoveInboundRequest(ClassMeta):
    tag: Optional[str] = None


@dataclass
class RemoveInboundResponse(ClassMeta):
    pass


@dataclass
class AlterInboundRequest(ClassMeta):
    tag: Optional[str] = None
    operation: Optional[TypedMessage] = None


@dataclass
class AlterInboundResponse(ClassMeta):
    pass


@dataclass
class AddOutboundRequest(ClassMeta):
    outbound: Optional[OutboundHandlerConfig] = None


@dataclass
class AddOutboundResponse(ClassMeta):
    pass


@dataclass
class RemoveOutboundRequest(ClassMeta):
    tag: Optional[str] = None


@dataclass
class RemoveOutboundResponse(ClassMeta):
    pass


@dataclass
class AlterOutboundRequest(ClassMeta):
    tag: Optional[str] = None
    operation: Optional[TypedMessage] = None


@dataclass
class AlterOutboundResponse(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n-xcapi/xray/app/proxyman/command/command.proto\x12\x19xray.app.proxyman.command\x1a%xcapi/xray/common/protocol/user.proto\x1a,xcapi/xray/common/serial/typed_message.proto\x1a\x1cxcapi/xray/core/config.proto\"<\n\x10\x41\x64\x64UserOperation\x12(\n\x04user\x18\x01 \x01(\x0b\x32\x1a.xray.common.protocol.User\"$\n\x13RemoveUserOperation\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x11\x41\x64\x64InboundRequest\x12\x30\n\x07inbound\x18\x01 \x01(\x0b\x32\x1f.xray.core.InboundHandlerConfig\"\x14\n\x12\x41\x64\x64InboundResponse\"#\n\x14RemoveInboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x17\n\x15RemoveInboundResponse\"W\n\x13\x41lterInboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\toperation\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\x16\n\x14\x41lterInboundResponse\"H\n\x12\x41\x64\x64OutboundRequest\x12\x32\n\x08outbound\x18\x01 \x01(\x0b\x32 .xray.core.OutboundHandlerConfig\"\x15\n\x13\x41\x64\x64OutboundResponse\"$\n\x15RemoveOutboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x18\n\x16RemoveOutboundResponse\"X\n\x14\x41lterOutboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\toperation\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\x17\n\x15\x41lterOutboundResponse\"\x08\n\x06\x43onfig2\xc5\x05\n\x0eHandlerService\x12k\n\nAddInbound\x12,.xray.app.proxyman.command.AddInboundRequest\x1a-.xray.app.proxyman.command.AddInboundResponse\"\x00\x12t\n\rRemoveInbound\x12/.xray.app.proxyman.command.RemoveInboundRequest\x1a\x30.xray.app.proxyman.command.RemoveInboundResponse\"\x00\x12q\n\x0c\x41lterInbound\x12..xray.app.proxyman.command.AlterInboundRequest\x1a/.xray.app.proxyman.command.AlterInboundResponse\"\x00\x12n\n\x0b\x41\x64\x64Outbound\x12-.xray.app.proxyman.command.AddOutboundRequest\x1a..xray.app.proxyman.command.AddOutboundResponse\"\x00\x12w\n\x0eRemoveOutbound\x12\x30.xray.app.proxyman.command.RemoveOutboundRequest\x1a\x31.xray.app.proxyman.command.RemoveOutboundResponse\"\x00\x12t\n\rAlterOutbound\x12/.xray.app.proxyman.command.AlterOutboundRequest\x1a\x30.xray.app.proxyman.command.AlterOutboundResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.proxyman.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ADDUSEROPERATION']._serialized_start = 191
    _globals['_ADDUSEROPERATION']._serialized_end = 251
    _globals['_REMOVEUSEROPERATION']._serialized_start = 253
    _globals['_REMOVEUSEROPERATION']._serialized_end = 289
    _globals['_ADDINBOUNDREQUEST']._serialized_start = 291
    _globals['_ADDINBOUNDREQUEST']._serialized_end = 360
    _globals['_ADDINBOUNDRESPONSE']._serialized_start = 362
    _globals['_ADDINBOUNDRESPONSE']._serialized_end = 382
    _globals['_REMOVEINBOUNDREQUEST']._serialized_start = 384
    _globals['_REMOVEINBOUNDREQUEST']._serialized_end = 419
    _globals['_REMOVEINBOUNDRESPONSE']._serialized_start = 421
    _globals['_REMOVEINBOUNDRESPONSE']._serialized_end = 444
    _globals['_ALTERINBOUNDREQUEST']._serialized_start = 446
    _globals['_ALTERINBOUNDREQUEST']._serialized_end = 533
    _globals['_ALTERINBOUNDRESPONSE']._serialized_start = 535
    _globals['_ALTERINBOUNDRESPONSE']._serialized_end = 557
    _globals['_ADDOUTBOUNDREQUEST']._serialized_start = 559
    _globals['_ADDOUTBOUNDREQUEST']._serialized_end = 631
    _globals['_ADDOUTBOUNDRESPONSE']._serialized_start = 633
    _globals['_ADDOUTBOUNDRESPONSE']._serialized_end = 654
    _globals['_REMOVEOUTBOUNDREQUEST']._serialized_start = 656
    _globals['_REMOVEOUTBOUNDREQUEST']._serialized_end = 692
    _globals['_REMOVEOUTBOUNDRESPONSE']._serialized_start = 694
    _globals['_REMOVEOUTBOUNDRESPONSE']._serialized_end = 718
    _globals['_ALTEROUTBOUNDREQUEST']._serialized_start = 720
    _globals['_ALTEROUTBOUNDREQUEST']._serialized_end = 808
    _globals['_ALTEROUTBOUNDRESPONSE']._serialized_start = 810
    _globals['_ALTEROUTBOUNDRESPONSE']._serialized_end = 833
    _globals['_CONFIG']._serialized_start = 835
    _globals['_CONFIG']._serialized_end = 843
    _globals['_HANDLERSERVICE']._serialized_start = 846
    _globals['_HANDLERSERVICE']._serialized_end = 1555
