syntax = "proto3";

package xray.transport.internet.headers.srtp;

message Config {
  uint32 version = 1;
	bool padding = 2;
	bool extension   = 3;
	uint32 csrc_count = 4;
	bool marker     = 5;
	uint32 payload_type = 6;
}
