# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/dns/fakedns/fakedns.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass


@dataclass
class FakeDnsPool(ClassMeta):
    ip_pool: Optional[str] = None
    """CIDR of IP pool used as fake DNS IP"""
    lruSize: Optional[int] = None
    """Size of Pool for remembering relationship between domain name and IP address"""


@dataclass
class FakeDnsPoolMulti(ClassMeta):
    pools: Optional[List[FakeDnsPool]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(xcapi/xray/app/dns/fakedns/fakedns.proto\x12\x14xray.app.dns.fakedns\"/\n\x0b\x46\x61keDnsPool\x12\x0f\n\x07ip_pool\x18\x01 \x01(\t\x12\x0f\n\x07lruSize\x18\x02 \x01(\x03\"D\n\x10\x46\x61keDnsPoolMulti\x12\x30\n\x05pools\x18\x01 \x03(\x0b\x32!.xray.app.dns.fakedns.FakeDnsPoolb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.dns.fakedns.fakedns_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_FAKEDNSPOOL']._serialized_start = 66
    _globals['_FAKEDNSPOOL']._serialized_end = 113
    _globals['_FAKEDNSPOOLMULTI']._serialized_start = 115
    _globals['_FAKEDNSPOOLMULTI']._serialized_end = 183
