# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/reverse/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from enum import Enum


@dataclass
class Control(ClassMeta):
    class State(Enum):
        ACTIVE: int = 0
        DRAIN: int = 1

    state: Optional[State] = None
    random: Optional[bytes] = None


@dataclass
class BridgeConfig(ClassMeta):
    tag: Optional[str] = None
    domain: Optional[str] = None


@dataclass
class PortalConfig(ClassMeta):
    tag: Optional[str] = None
    domain: Optional[str] = None


@dataclass
class Config(ClassMeta):
    bridge_config: Optional[List[BridgeConfig]] = None
    portal_config: Optional[List[PortalConfig]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#xcapi/xray/app/reverse/config.proto\x12\x10xray.app.reverse\"i\n\x07\x43ontrol\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1f.xray.app.reverse.Control.State\x12\x0e\n\x06random\x18\x63 \x01(\x0c\"\x1e\n\x05State\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\t\n\x05\x44RAIN\x10\x01\"+\n\x0c\x42ridgeConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"+\n\x0cPortalConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"v\n\x06\x43onfig\x12\x35\n\rbridge_config\x18\x01 \x03(\x0b\x32\x1e.xray.app.reverse.BridgeConfig\x12\x35\n\rportal_config\x18\x02 \x03(\x0b\x32\x1e.xray.app.reverse.PortalConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.reverse.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONTROL']._serialized_start = 57
    _globals['_CONTROL']._serialized_end = 162
    _globals['_CONTROL_STATE']._serialized_start = 132
    _globals['_CONTROL_STATE']._serialized_end = 162
    _globals['_BRIDGECONFIG']._serialized_start = 164
    _globals['_BRIDGECONFIG']._serialized_end = 207
    _globals['_PORTALCONFIG']._serialized_start = 209
    _globals['_PORTALCONFIG']._serialized_end = 252
    _globals['_CONFIG']._serialized_start = 254
    _globals['_CONFIG']._serialized_end = 372
