syntax = "proto3";

package xray.proxy.dns;

import "xcapi/xray/common/net/destination.proto";

message Config {
  // Server is the DNS server address. If specified, this address overrides the
  // original one.
  xray.common.net.Endpoint server = 1;
  uint32 user_level = 2;
  string non_IP_query = 3;
  repeated int32 block_types = 4;
}
