# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.stats.command import command_pb


class StatsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/GetStats',
            request_serializer=command_pb.GetStatsRequest.SerializeToString,
            response_deserializer=command_pb.GetStatsResponse.FromString,
            _registered_method=True)
        self.QueryStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/QueryStats',
            request_serializer=command_pb.QueryStatsRequest.SerializeToString,
            response_deserializer=command_pb.QueryStatsResponse.FromString,
            _registered_method=True)
        self.GetSysStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/GetSysStats',
            request_serializer=command_pb.SysStatsRequest.SerializeToString,
            response_deserializer=command_pb.SysStatsResponse.FromString,
            _registered_method=True)
