syntax = "proto3";

package xray.transport.internet.splithttp;

message Config {
  string host = 1;
  string path = 2;
  map<string, string> header = 3;
  RandRangeConfig scMaxConcurrentPosts = 4;
  RandRangeConfig scMaxEachPostBytes = 5;
  RandRangeConfig scMinPostsIntervalMs = 6;
  bool noSSEHeader = 7;
  RandRangeConfig xPaddingBytes = 8;
  Multiplexing xmux = 9;
}

message RandRangeConfig {
    int32 from = 1;
    int32 to = 2;
}

message Multiplexing {
  RandRangeConfig maxConcurrency = 1;
  RandRangeConfig maxConnections = 2;
  RandRangeConfig cMaxReuseTimes = 3;
  RandRangeConfig cMaxLifetimeMs = 4;
}
