syntax = "proto3";

package xray.common.protocol;

enum SecurityType {
  UNKNOWN = 0;
  AUTO = 2;
  AES128_GCM = 3;
  CHACHA20_POLY1305 = 4;
  NONE = 5; // [DEPRECATED 2023-06] 
  ZERO = 6;
}

message SecurityConfig {
  SecurityType type = 1;
}
