syntax = "proto3";

package xray.transport.internet.grpc.encoding;

message Hunk {
  bytes data = 1;
}

message MultiHunk {
   repeated bytes data = 1;
}

service GRPCService {
  rpc Tun (stream Hunk) returns (stream Hunk);
  rpc TunMulti (stream MultiHunk) returns (stream MultiHunk);
}
