syntax = "proto3";

package xray.proxy.trojan;

import "xcapi/xray/common/protocol/user.proto";
import "xcapi/xray/common/protocol/server_spec.proto";

message Account {
  string password = 1;
}

message Fallback {
  string name = 1;
  string alpn = 2;
  string path = 3;
  string type = 4;
  string dest = 5;
  uint64 xver = 6;
}

message ClientConfig {
  repeated xray.common.protocol.ServerEndpoint server = 1;
}

message ServerConfig {
  repeated xray.common.protocol.User users = 1;
  repeated Fallback fallbacks = 2;
}
