# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/protocol/headers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass
from enum import Enum


class SecurityType(Enum):
    UNKNOWN: int = 0
    AUTO: int = 2
    AES128_GCM: int = 3
    CHACHA20_POLY1305: int = 4
    NONE: int = 5
    """deprecated 2023-06"""
    ZERO: int = 6


@dataclass
class SecurityConfig(ClassMeta):
    type: Optional[SecurityType] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(xcapi/xray/common/protocol/headers.proto\x12\x14xray.common.protocol\"B\n\x0eSecurityConfig\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".xray.common.protocol.SecurityType*`\n\x0cSecurityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x02\x12\x0e\n\nAES128_GCM\x10\x03\x12\x15\n\x11\x43HACHA20_POLY1305\x10\x04\x12\x08\n\x04NONE\x10\x05\x12\x08\n\x04ZERO\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.protocol.headers_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SECURITYTYPE']._serialized_start = 134
    _globals['_SECURITYTYPE']._serialized_end = 230
    _globals['_SECURITYCONFIG']._serialized_start = 66
    _globals['_SECURITYCONFIG']._serialized_end = 132
