syntax = "proto3";

package xray.proxy.socks;

import "xcapi/xray/common/net/address.proto";
import "xcapi/xray/common/protocol/server_spec.proto";

// Account represents a Socks account.
message Account {
  string username = 1;
  string password = 2;
}

// AuthType is the authentication type of Socks proxy.
enum AuthType {
  // NO_AUTH is for anonymous authentication.
  NO_AUTH = 0;
  // PASSWORD is for username/password authentication.
  PASSWORD = 1;
}

// ServerConfig is the protobuf config for Socks server.
message ServerConfig {
  AuthType auth_type = 1;
  map<string, string> accounts = 2;
  xray.common.net.IPOrDomain address = 3;
  bool udp_enabled = 4;
  uint32 user_level = 6;
}

// ClientConfig is the protobuf config for Socks client.
message ClientConfig {
  // Sever is a list of Socks server addresses.
  repeated xray.common.protocol.ServerEndpoint server = 1;
}
