# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/observatory/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.app.observatory.config_pb import ObservationResult
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class GetOutboundStatusRequest(ClassMeta):
    pass


@dataclass
class GetOutboundStatusResponse(ClassMeta):
    status: Optional[ObservationResult] = None


@dataclass
class Config(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n0xcapi/xray/app/observatory/command/command.proto\x12!xray.core.app.observatory.command\x1a\'xcapi/xray/app/observatory/config.proto\"\x1a\n\x18GetOutboundStatusRequest\"Y\n\x19GetOutboundStatusResponse\x12<\n\x06status\x18\x01 \x01(\x0b\x32,.xray.core.app.observatory.ObservationResult\"\x08\n\x06\x43onfig2\xa7\x01\n\x12ObservatoryService\x12\x90\x01\n\x11GetOutboundStatus\x12;.xray.core.app.observatory.command.GetOutboundStatusRequest\x1a<.xray.core.app.observatory.command.GetOutboundStatusResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.observatory.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETOUTBOUNDSTATUSREQUEST']._serialized_start = 128
    _globals['_GETOUTBOUNDSTATUSREQUEST']._serialized_end = 154
    _globals['_GETOUTBOUNDSTATUSRESPONSE']._serialized_start = 156
    _globals['_GETOUTBOUNDSTATUSRESPONSE']._serialized_end = 245
    _globals['_CONFIG']._serialized_start = 247
    _globals['_CONFIG']._serialized_end = 255
    _globals['_OBSERVATORYSERVICE']._serialized_start = 258
    _globals['_OBSERVATORYSERVICE']._serialized_end = 425
