syntax = "proto3";

package xray.transport.internet.reality;

message Config {
  bool show = 1;
  string dest = 2;
  string type = 3;
  uint64 xver = 4;
  repeated string server_names = 5;
  bytes private_key = 6;
  bytes min_client_ver = 7;
  bytes max_client_ver = 8;
  uint64 max_time_diff = 9;
  repeated bytes short_ids = 10;

  string Fingerprint = 21;
  string server_name = 22;
  bytes public_key = 23;
  bytes short_id = 24;
  string spider_x = 25;
  repeated int64 spider_y = 26;
  string master_key_log = 27;
}
