# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.log.command import config_pb


class LoggerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RestartLogger = channel.unary_unary(
                '/xray.app.log.command.LoggerService/RestartLogger',
                request_serializer=config_pb.RestartLoggerRequest.SerializeToString,
                response_deserializer=config_pb.RestartLoggerResponse.FromString,
                _registered_method=True)
