# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/log/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.log.log_pb import Severity
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass
from enum import Enum


@dataclass
class LogType(Enum):
    Nil: int = 0
    """None"""
    Console: int = 1
    File: int = 2
    Event: int = 3


class Config(ClassMeta):
    error_log_type: Optional[LogType] = None
    error_log_level: Optional[Severity] = None
    error_log_path: Optional[str] = None
    access_log_type: Optional[LogType] = None
    access_log_path: Optional[str] = None
    enable_dns_log: Optional[bool] = None
    mask_address: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fxcapi/xray/app/log/config.proto\x12\x0cxray.app.log\x1a\x1fxcapi/xray/common/log/log.proto\"\xfa\x01\n\x06\x43onfig\x12-\n\x0e\x65rror_log_type\x18\x01 \x01(\x0e\x32\x15.xray.app.log.LogType\x12\x32\n\x0f\x65rror_log_level\x18\x02 \x01(\x0e\x32\x19.xray.common.log.Severity\x12\x16\n\x0e\x65rror_log_path\x18\x03 \x01(\t\x12.\n\x0f\x61\x63\x63\x65ss_log_type\x18\x04 \x01(\x0e\x32\x15.xray.app.log.LogType\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x05 \x01(\t\x12\x16\n\x0e\x65nable_dns_log\x18\x06 \x01(\x08\x12\x14\n\x0cmask_address\x18\x07 \x01(\t*5\n\x07LogType\x12\x08\n\x04None\x10\x00\x12\x0b\n\x07\x43onsole\x10\x01\x12\x08\n\x04\x46ile\x10\x02\x12\t\n\x05\x45vent\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.log.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_LOGTYPE']._serialized_start = 335
    _globals['_LOGTYPE']._serialized_end = 388
    _globals['_CONFIG']._serialized_start = 83
    _globals['_CONFIG']._serialized_end = 333
