# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/stats/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class GetStatsRequest(ClassMeta):
    name: Optional[str] = None
    """Name of the stat counter."""
    reset: Optional[bool] = None
    """Whether or not to reset the counter to fetching its value."""


@dataclass
class Stat(ClassMeta):
    name: Optional[str] = None
    value: Optional[int] = None


@dataclass
class GetStatsResponse(ClassMeta):
    stat: Optional[Stat] = None


@dataclass
class QueryStatsRequest(ClassMeta):
    pattern: Optional[str] = None
    reset: Optional[bool] = None


@dataclass
class QueryStatsResponse(ClassMeta):
    stat: Optional[List[Stat]] = None


@dataclass
class SysStatsRequest(ClassMeta):
    pass


@dataclass
class SysStatsResponse(ClassMeta):
    NumGoroutine: Optional[int] = None
    NumGC: Optional[int] = None
    Alloc: Optional[int] = None
    TotalAlloc: Optional[int] = None
    Sys: Optional[int] = None
    Mallocs: Optional[int] = None
    Frees: Optional[int] = None
    LiveObjects: Optional[int] = None
    PauseTotalNs: Optional[int] = None
    Uptime: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*xcapi/xray/app/stats/command/command.proto\x12\x16xray.app.stats.command\".\n\x0fGetStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05reset\x18\x02 \x01(\x08\"#\n\x04Stat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\">\n\x10GetStatsResponse\x12*\n\x04stat\x18\x01 \x01(\x0b\x32\x1c.xray.app.stats.command.Stat\"3\n\x11QueryStatsRequest\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12\r\n\x05reset\x18\x02 \x01(\x08\"@\n\x12QueryStatsResponse\x12*\n\x04stat\x18\x01 \x03(\x0b\x32\x1c.xray.app.stats.command.Stat\"\x11\n\x0fSysStatsRequest\"\xc2\x01\n\x10SysStatsResponse\x12\x14\n\x0cNumGoroutine\x18\x01 \x01(\r\x12\r\n\x05NumGC\x18\x02 \x01(\r\x12\r\n\x05\x41lloc\x18\x03 \x01(\x04\x12\x12\n\nTotalAlloc\x18\x04 \x01(\x04\x12\x0b\n\x03Sys\x18\x05 \x01(\x04\x12\x0f\n\x07Mallocs\x18\x06 \x01(\x04\x12\r\n\x05\x46rees\x18\x07 \x01(\x04\x12\x13\n\x0bLiveObjects\x18\x08 \x01(\x04\x12\x14\n\x0cPauseTotalNs\x18\t \x01(\x04\x12\x0e\n\x06Uptime\x18\n \x01(\r\"\x08\n\x06\x43onfig2\xba\x02\n\x0cStatsService\x12_\n\x08GetStats\x12\'.xray.app.stats.command.GetStatsRequest\x1a(.xray.app.stats.command.GetStatsResponse\"\x00\x12\x65\n\nQueryStats\x12).xray.app.stats.command.QueryStatsRequest\x1a*.xray.app.stats.command.QueryStatsResponse\"\x00\x12\x62\n\x0bGetSysStats\x12\'.xray.app.stats.command.SysStatsRequest\x1a(.xray.app.stats.command.SysStatsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.stats.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETSTATSREQUEST']._serialized_start = 70
    _globals['_GETSTATSREQUEST']._serialized_end = 116
    _globals['_STAT']._serialized_start = 118
    _globals['_STAT']._serialized_end = 153
    _globals['_GETSTATSRESPONSE']._serialized_start = 155
    _globals['_GETSTATSRESPONSE']._serialized_end = 217
    _globals['_QUERYSTATSREQUEST']._serialized_start = 219
    _globals['_QUERYSTATSREQUEST']._serialized_end = 270
    _globals['_QUERYSTATSRESPONSE']._serialized_start = 272
    _globals['_QUERYSTATSRESPONSE']._serialized_end = 336
    _globals['_SYSSTATSREQUEST']._serialized_start = 338
    _globals['_SYSSTATSREQUEST']._serialized_end = 355
    _globals['_SYSSTATSRESPONSE']._serialized_start = 358
    _globals['_SYSSTATSRESPONSE']._serialized_end = 552
    _globals['_CONFIG']._serialized_start = 554
    _globals['_CONFIG']._serialized_end = 562
    _globals['_STATSSERVICE']._serialized_start = 565
    _globals['_STATSSERVICE']._serialized_end = 879
