syntax = "proto3";

package xray.common.protocol;
import "xcapi/xray/common/serial/typed_message.proto";

// User is a generic user for all protocols.
message User {
  uint32 level = 1;
  string email = 2;

  // Protocol specific account information. Must be the account proto in one of
  // the proxies.
  xray.common.serial.TypedMessage account = 3;
}
