syntax = "proto3";

package xray.proxy.vmess;

import "xcapi/xray/common/protocol/headers.proto";

message Account {
  // ID of the account, in the form of a UUID, e.g.,
  // "66ad4540-b58c-4ad2-9926-ea63445a9b57".
  string id = 1;
  // Security settings. Only applies to client side.
  xray.common.protocol.SecurityConfig security_settings = 3;
  // Define tests enabled for this account
  string tests_enabled = 4;
}
